Skip to contents

Analysis tools for ChIP-Seq peak data including overlap analysis, peak annotation, and visualization with Shiny applications.

Details

The bccAnalysis package provides tools for processing GRanges objects from narrowPeak files, performing overlap analysis, peak annotation using ChIPseeker, and interactive Shiny applications for visualization.

See also

Author

Jacob Martin